"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DataSourceManager = void 0;
/**
 * 数据源管理器实现
 */
const extend_1 = require("../util/extend");
const error_1 = require("../error");
class DataSourceManager {
    constructor() {
        this.dataSource = new Map();
        this.options = {};
    }
    async initDataSource(options = {}) {
        this.options = options;
        if (options.dataSource) {
            for (const dataSourceName in options.dataSource) {
                // create data source
                await this.createInstance(options.dataSource[dataSourceName], dataSourceName);
            }
        }
        else {
            throw new error_1.MidwayParameterError('DataSourceManager must set options.dataSource.');
        }
    }
    /**
     * get a data source instance
     * @param dataSourceName
     */
    getDataSource(dataSourceName) {
        return this.dataSource.get(dataSourceName);
    }
    /**
     * check data source has exists
     * @param dataSourceName
     */
    hasDataSource(dataSourceName) {
        return this.dataSource.has(dataSourceName);
    }
    getDataSourceNames() {
        return Array.from(this.dataSource.keys());
    }
    /**
     * check the data source is connected
     * @param dataSourceName
     */
    async isConnected(dataSourceName) {
        return this.checkConnected(this.getDataSource(dataSourceName));
    }
    async createInstance(config, clientName) {
        // options.default will be merge in to options.clients[id]
        config = (0, extend_1.extend)(true, {}, this.options['default'], config);
        const client = await this.createDataSource(config, clientName);
        if (client) {
            if (clientName) {
                this.dataSource.set(clientName, client);
            }
            return client;
        }
    }
    async destroyDataSource(dataSource) { }
    async stop() {
        for (const value of this.dataSource.values()) {
            await this.destroyDataSource(value);
        }
    }
}
exports.DataSourceManager = DataSourceManager;
//# sourceMappingURL=dataSourceManager.js.map